@@ -1,6 +1,7 @@
 import datetime
 import json
 import os
+import pathlib
 from functools import partial
 from multiprocessing.pool import Pool
 
@@ -236,13 +237,22 @@ def upload_packed(ctx, import_request, packed):
 
 
 @api.command()
-@click.option('-r', '--retailer')
-@click.option('-m', '--model', )
+@click.option('-r', '--retailer', help="Retailer codename", prompt=True)
+@click.option('-m', '--model', help="Model codename", prompt=True)
 @click.option('-i', '--images', type=click.Path(exists=True, file_okay=False, dir_okay=True))
 @click.option('-l', '--labels', type=click.Path(exists=True, file_okay=True, dir_okay=False))
 @click.option('-f', '--features', type=click.Path(exists=True, file_okay=True, dir_okay=False))
 @pass_rebotics_context
 def pack_and_import_classification_db(ctx, retailer, model, images, labels, features):
+    """
+        Pack classification database to single .rcdb file and import it to the Rebotics Admin
+db/
+├── custom_folder
+│   ├── image_400x400_copy.png
+│   └── image_400x400.png
+├── features.txt
+└── labels.txt
+    """
     packer = ClassificationDatabasePacker(destination=None)
     if ctx.verbose:
         click.echo("Packing from provided values: \n"
@@ -262,11 +272,14 @@ def pack_and_import_classification_db(ctx, retailer, model, images, labels, feat
 
 
 @api.command()
-@click.option('-r', '--retailer')
-@click.option('-m', '--model', )
+@click.option('-r', '--retailer', help="Retailer codename", prompt=True)
+@click.option('-m', '--model', help="Model codename", prompt=True)
 @click.argument('filepath', type=click.Path(exists=True, file_okay=True, dir_okay=False))
 @pass_rebotics_context
 def import_classification_db(ctx, retailer, model, filepath):
+    """
+    Import rcdb file to Rebotics Admin
+    """
     extension = os.path.split(filepath)[-1].split('.')[-1]
     import_request = ctx.provider.create_classification_database_import(
         retailer=retailer, model=model, extension=extension
@@ -275,6 +288,41 @@ def import_classification_db(ctx, retailer, model, filepath):
         upload_packed(ctx, import_request, packed)
 
 
+@api.command()
+@click.option('-i', '--images', type=click.Path(exists=True, file_okay=False, dir_okay=True))
+@click.option('-l', '--labels', type=click.Path(exists=True, file_okay=True, dir_okay=False))
+@click.option('-f', '--features', type=click.Path(exists=True, file_okay=True, dir_okay=False))
+@click.option('-t', '--target', type=click.Path(exists=True, file_okay=True, dir_okay=True), default='.')
+@pass_rebotics_context
+def pack_classification_db(ctx, images, labels, features, target):
+    """
+        Pack classification database to single .rcdb file
+db/
+├── custom_folder
+│   ├── image_400x400_copy.png
+│   └── image_400x400.png
+├── features.txt
+└── labels.txt
+    """
+    target = pathlib.Path(target)
+    if target.is_dir():
+        target = target / "{}.{}".format(
+            datetime.datetime.now().strftime('%Y-%m-%dZ%H:%M'),
+            ClassificationDatabasePacker.extension
+        )
+    packer = ClassificationDatabasePacker(destination=target)
+    if ctx.verbose:
+        click.echo("Packing from provided values: \n"
+                   "labels: {labels} \n"
+                   "features: {features} \n"
+                   "images: {images}".format(labels=labels, features=features, images=images))
+    try:
+        packed = packer.pack(labels, features, images)
+    except ClassificationDatabaseException as exc:
+        raise click.ClickException(str(exc))
+    click.echo('Written to {}'.format(packed))
+
+
 api.add_command(shell, 'shell')
 api.add_command(roles, 'roles')
 api.add_command(configure, 'configure')
